# --------------------------------------------------------------
# Applied Statistics / Statistical methods for the Biosciences
# Solution of Exercise 3.1
# Bo Markussen
# December 4, 2021
# --------------------------------------------------------------

# First some comments about installing the gof-package:
# Unfortunately it is not available on CRAN. So you will have to install
# it from the GitHub page of the package author, Klaus K. Holst.
# Furthermore, the package use c++ code, so Windows user will have first to
# to install what is known as RTools. Thus, here are the steps that you
# should do:

# Step 1: If you have a Mac, then this is already done!
# Step 1: If you have a Windows PC, then install RTools from the homepage
https://cran.r-project.org/bin/windows/Rtools/

# Step 2: Install the devtools-package
install.packages("devtools")

# Step 3: Install the gof-package
devtools::install_github("kkholst/gof",upgrade="never")
  
# Read data
beetle_A <- read.delim("beetle.txt")
beetle_B <- read.delim("beetle_long.txt")
beetle_C <- read.delim("beetle_verylong.txt")

# Make probit analysis for the different data representations
m_A <- glm(cbind(y,n-y)~x,data=beetle_A,family=binomial(link="probit"))
m_B <- glm(factor(status)~x,weights=count,data=beetle_B,family=binomial(link="probit"))
m_C <- glm(factor(status)~x,data=beetle_C,family=binomial(link="probit"))

# Remarks:
# 1) The data frames 'beetle_B' and 'beetle_C' both have a binary representation of
#    the datasets, where the response variable 'status' is dead or alive. Please note that glm()
#    models the probability of the last level of the response variable. In the present case
#    the probility of "dead" (as "dead" comes after "alive" alphabetically).
# 2) The "factor" in m_B and m_C is needed since read.delim() loads the variable
#    "status" as a character string. And this does not work together with glm(), which can not 
#    accept a string as the response variable. So we use "factor()" to make "status" into a 
#    categorical factor.
# 3) The difference between 'beetle_B' and 'beetle_C' is that the former contains 
#    a variable 'count' that tells how many of these observations are present. Such a variable,
#    sometimes called a 'frequency variable', should be given in the weights-option.
# 4) The data frame 'beetle_A' provides a binomial representation of the datasets. The response should
#    be given by binding number of successes (here 'dead') together with number of faliures
#    (here 'alive) using the cbind() function.

# The 3 data representations will (of course) give the same parameter estimates and the
# same p-values for the effect tests.
summary(m_A)
summary(m_B)
summary(m_C)

# The same of course also goes for the Goodness-of-Fit test, which however, does
# not support data represented via a frequency variable. So for m_B you can 
# not use the cumres() function. 
library(gof)
x1()
plot(cumres(m_A))
plot(cumres(m_B))
plot(cumres(m_C))

# Remark: Above the function x11() is used to open an external
#   graphical window with sufficient spaca to contain the figure.

# Remark: Apparently cumres() does not work on "large" datasets!? 
#   This does not seem to be the case for the beetles example,
#   but it is the case for the company-default example considered
#   at the lectures!
