# --------------------------------------------------------------
# Applied Statistics / Statistical methods for the Biosciences
# Day 3: Categorical regression
# Solution to Exercise 3.3
# Bo Markussen
# December 3, 2020
# --------------------------------------------------------------

# Load libraries we will be using
library(gof)

# Read data
gla <- read.delim("GLA.txt")

# Make logistic regression
m1 <- glm(cbind(positive,negative)~factor(herd)+factor(clin),data=gla,family=binomial)

# Model validation using cumulative residuals:
# We see, that the model is valid!
x11()
plot(cumres(m1))

# Is there an effect of the clinical evaluation (hypothesis test): Yes, p=0.004023 (**)
# Herds are also very different (p=0.0000004537)
drop1(m1,test="Chisq")

# Estimates and confidence intervals for the model parameters
cbind(estimate=coef(m1),confint(m1))

# The above estimates are associated to the log odds ratios.
# To get odds ratios we backtransform by taking the exponential function. 
exp(cbind(OR=coef(m1),confint(m1)))

# And if we only want these with 4 decimales and for the clinical evaluation variables
round(exp(cbind(OR=coef(m1),confint(m1))[11:13,]),digits=4)

# Alternatively, we may use the emmeans package to present the estimates.
# Let's try this. First we find the probabilities for being "positive" among
# the different clinical scores
library(emmeans)
emmeans(m1,~clin,type="response")

# Secondly we compute the odds ratios for being "positive" between the clinical scores.
# Quiz: Try to match with the results found by the code in line 34
confint(pairs(emmeans(m1,~clin),type="response",reverse=TRUE))
