# --------------------------------------------------------------
# Applied Statistics / Statistical methods for the Biosciences
# Day 3: Categorical regression
# Solution to Exercise 3.5
# Bo Markussen
# December 1, 2018
# --------------------------------------------------------------

# Load libraries we will be using
library(gof)
library(emmeans)

# Read data
particles <- read.delim("particles.txt")
names(particles)

# Remark: This dataset is already on the "long format". Thus, 
# each row encodes 1 observation of a count response!
head(particles)

# Initial logistic regression
m1 <- glm(count~location+type*depth,data=particles,family=poisson())

# Model validation using cumulative residuals
x11()
plot(cumres(m1))

# The model validity is borderline, so we try to allow for larger dispersion
# using the quasipoisson family (see section 10.1.2 in the R guide):
m2 <- glm(count~location+type*depth,data=particles,family=quasipoisson())

# Model validation using cumulative residuals: Better, in particular when inspecting the 
# Goodness-of-Fit tests (now p-values around 8% and 70%, instead of two values close to 5%).
plot(cumres(m2))

# Let's do hypothesis tests (Is there an effect?)
drop1(m2,test="Chisq")

# The interaction between type and depth is highly significant (***), ie. the occurance of the
# particle types vary with the depth. And although the location is not significant (p=0.6911)
# we keep it in the model anyway.

# The parameter estimates are like this:
cbind(estimate=coef(m1),confint(m1))

# And the wanted log(relative risk) is like this:
confint(pairs(emmeans(m2,~type|depth),reverse=TRUE),adjust="none")

# From this we extract the wanted result:
# depth = 11-14 meters:
#  contrast                           estimate     SE  df asymp.LCL asymp.UCL
#  Sediment_grains - Quartz_grains      -1.950 0.1864 Inf    -2.315    -1.584

# And the wanted relative risk is like this:
# Remark: the option type="response" makes R backtransform using the exponential function
confint(pairs(emmeans(m2,~type|depth),reverse=TRUE),adjust="none",type="response")

# From this we extract the wanted result:
# depth = 11-14 meters:
#  contrast                            ratio     SE  df asymp.LCL asymp.UCL
#  Sediment_grains / Quartz_grains     0.142 0.0265 Inf    0.0987     0.205

# The wanted reletive risk it self may be found by a simple computed as done
# below. However, a priori this comes without confidence intervals etc.
(23+14)/(133+127)
